@@ -1,6 +1,6 @@
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * gog-axis.h : 
+ * gog-axis.h :
  *
  * Copyright (C) 2003-2004 Jody Goldberg (jody@gnome.org)
  *
@@ -22,10 +22,7 @@
 #ifndef GOG_AXIS_H
 #define GOG_AXIS_H
 
-#include <goffice/graph/gog-axis-line.h>
-#include <goffice/graph/goffice-graph.h>
-#include <goffice/data/go-data.h>
-#include <glib-object.h>
+#include <goffice/goffice.h>
 
 G_BEGIN_DECLS
 
@@ -68,9 +65,9 @@ gboolean      gog_axis_map_is_inverted 	  (GogAxisMap *map);
 
 /*****************************************************************************/
 
-#define GOG_AXIS_TYPE	(gog_axis_get_type ())
-#define GOG_AXIS(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_AXIS_TYPE, GogAxis))
-#define IS_GOG_AXIS(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_AXIS_TYPE))
+#define GOG_TYPE_AXIS	(gog_axis_get_type ())
+#define GOG_AXIS(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_AXIS, GogAxis))
+#define GOG_IS_AXIS(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_AXIS))
 
 GType gog_axis_get_type (void);
 
@@ -89,7 +86,7 @@ unsigned      gog_axis_get_ticks 	  (GogAxis *axis, GogAxisTick **ticks);
 GOData	     *gog_axis_get_labels	  (GogAxis const *axis,
 					   GogPlot **plot_that_labeled_axis);
 
-double 	      gog_axis_get_entry 	  (GogAxis const *axis, GogAxisElemType i, 
+double 	      gog_axis_get_entry 	  (GogAxis const *axis, GogAxisElemType i,
 					   gboolean *user_defined);
 
 void 	      gog_axis_add_contributor	  (GogAxis *axis, GogObject *contrib);
