@@ -160,7 +160,7 @@ gog_series_element_populate_editor (GogObject *gobj,
 	if (gse_vbox == NULL) {
 		vbox = gtk_vbox_new (FALSE, 6);
 		gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
-	} else 
+	} else
 		vbox = gse_vbox;
 	gtk_box_pack_start (GTK_BOX (vbox), w, FALSE, FALSE, 0);
 	gtk_box_reorder_child (GTK_BOX (vbox), w, 0);
@@ -184,7 +184,8 @@ gog_series_element_init_style (GogStyledObject *gso, GOStyle *style)
 	parent_style = go_styled_object_get_style (GO_STYLED_OBJECT (series));
 	style->interesting_fields = parent_style->interesting_fields;
 	gog_theme_fillin_style (gog_object_get_theme (GOG_OBJECT (gso)),
-		style, GOG_OBJECT (gso), GOG_SERIES_ELEMENT (gso)->index, FALSE);
+		style, GOG_OBJECT (gso), GOG_SERIES_ELEMENT (gso)->index,
+	        style->interesting_fields);
 }
 
 static void
@@ -206,14 +207,14 @@ gog_series_element_class_init (GogSeriesElementClass *klass)
 	gog_klass->use_parent_as_proxy  = TRUE;
 
 	g_object_class_install_property (gobject_klass, ELEMENT_INDEX,
-		g_param_spec_int ("index", 
+		g_param_spec_int ("index",
 			_("Index"),
 			_("Index of the corresponding data element"),
 			0, G_MAXINT, 0,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT | GOG_PARAM_FORCE_SAVE));
 }
 
-GSF_CLASS (GogSeriesElement, gog_series_element,
+GSF_CLASS_ABSTRACT (GogSeriesElement, gog_series_element,
 	   gog_series_element_class_init, NULL /*gog_series_element_init*/,
 	   GOG_TYPE_STYLED_OBJECT)
 
@@ -405,9 +406,9 @@ cb_show_in_legend (GtkToggleButton *b, GObject *series)
 static void
 cb_line_interpolation_changed (GtkComboBox *box, GogSeries *series)
 {
-	GladeXML *gui = g_object_get_data (G_OBJECT (box), "gui");
+	GtkBuilder *gui = g_object_get_data (G_OBJECT (box), "gui");
 	GtkWidget *widget = GTK_WIDGET (g_object_get_data (G_OBJECT(box), "skip-button"));
-	GtkWidget *table = glade_xml_get_widget (gui, "clamps-table");
+	GtkWidget *table = go_gtk_builder_get_widget (gui, "clamps-table");
 	series->interpolation = gtk_combo_box_get_active (box);
 	gtk_widget_set_sensitive (widget, !go_line_interpolation_auto_skip (series->interpolation));
 	widget = GTK_WIDGET (g_object_get_data (G_OBJECT(box), "fill-type"));
@@ -517,17 +518,17 @@ gog_series_populate_editor (GogObject *gobj,
 
 	box = go_editor_get_registered_widget (editor, "line_box");
 	if (series_class->has_interpolation && box != NULL) {
-		GladeXML *gui;
+		GtkBuilder *gui;
 		GtkWidget *widget;
 
-		gui = go_glade_new ("gog-series-prefs.glade", "interpolation_prefs", GETTEXT_PACKAGE, cc);
+		gui = go_gtk_builder_new ("gog-series-prefs.ui", GETTEXT_PACKAGE, cc);
 		if (gui != NULL) {
 			int i;
 			GogAxisSet set = gog_plot_axis_set_pref (gog_series_get_plot (series));
 			GogDataset *clamp_set = gog_series_get_interpolation_params (series);
-			widget = glade_xml_get_widget (gui, "interpolation_prefs");
+			widget = go_gtk_builder_get_widget (gui, "interpolation_prefs");
 			gtk_box_pack_start (GTK_BOX (box), widget, FALSE, FALSE, 0);
-			widget = glade_xml_get_widget (gui, "interpolation-table");
+			widget = go_gtk_builder_get_widget (gui, "interpolation-table");
 			/* create an interpolation type combo and populate it */
 			combo = GTK_COMBO_BOX (gtk_combo_box_new_text ());
 			if (set & 1 << GOG_AXIS_RADIAL)
@@ -545,8 +546,8 @@ gog_series_populate_editor (GogObject *gobj,
 					  0, 1, (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
 					  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), 0, 0);
 			gtk_widget_show_all (widget);
-			widget = glade_xml_get_widget (gui, "interpolation-skip-invalid");
-			g_object_set_data (G_OBJECT (combo), "skip-button", widget); 
+			widget = go_gtk_builder_get_widget (gui, "interpolation-skip-invalid");
+			g_object_set_data (G_OBJECT (combo), "skip-button", widget);
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), series->interpolation_skip_invalid);
 			if (go_line_interpolation_auto_skip (series->interpolation))
 				gtk_widget_set_sensitive (widget, FALSE);
@@ -554,29 +555,31 @@ gog_series_populate_editor (GogObject *gobj,
 					  G_CALLBACK (cb_line_interpolation_skip_changed), series);
 			if (clamp_set) {
 				GtkWidget *w;
-				widget = glade_xml_get_widget (gui, "clamps-table");
+				widget = go_gtk_builder_get_widget (gui, "clamps-table");
 				w = GTK_WIDGET (gog_data_allocator_editor (dalloc, clamp_set, 0, GOG_DATA_SCALAR));
+				gtk_widget_set_tooltip_text (w, _("Derivative at first point of the clamped cubic spline."));
 				gtk_widget_show (w);
 				gtk_table_attach (GTK_TABLE (widget), w, 1, 2, 0, 1, GTK_FILL | GTK_EXPAND, 0, 0, 0);
 				w = GTK_WIDGET (gog_data_allocator_editor (dalloc, clamp_set, 1, GOG_DATA_SCALAR));
+				gtk_widget_set_tooltip_text (w, _("Derivative at last point of the clamped cubic spline."));
 				gtk_widget_show (w);
 				gtk_table_attach (GTK_TABLE (widget), w, 1, 2, 1, 2, GTK_FILL | GTK_EXPAND, 0, 0, 0);
 				if (series->interpolation != GO_LINE_INTERPOLATION_CLAMPED_CUBIC_SPLINE)
 					gtk_widget_hide (widget);
 			}
-			g_object_set_data_full (G_OBJECT (combo), "gui", gui,
-						(GDestroyNotify) g_object_unref);
+			g_object_set_data (G_OBJECT (combo), "gui", gui);
+			g_signal_connect_swapped (G_OBJECT (combo), "destroy", G_CALLBACK (g_object_unref), gui);
 		}
 	}
 
 	box = go_editor_get_registered_widget (editor, "fill_extension_box");
 	if (series_class->has_fill_type && box != NULL) {
-		GladeXML *gui;
+		GtkBuilder *gui;
 		GtkWidget *widget;
 
-		gui = go_glade_new ("gog-series-prefs.glade", "fill_type_prefs", GETTEXT_PACKAGE, cc);
+		gui = go_gtk_builder_new ("gog-series-prefs.ui", GETTEXT_PACKAGE, cc);
 		if (gui != NULL) {
-			widget = glade_xml_get_widget (gui, "fill_type_combo");
+			widget = go_gtk_builder_get_widget (gui, "fill_type_combo");
 			gog_series_populate_fill_type_combo (GOG_SERIES (series), GTK_COMBO_BOX (widget));
 			g_signal_connect (G_OBJECT (widget), "changed",
 					  G_CALLBACK (cb_fill_type_changed), series);
@@ -584,7 +587,7 @@ gog_series_populate_editor (GogObject *gobj,
 				g_object_set_data (G_OBJECT (combo), "fill-type", widget);
 			if (series->interpolation == GO_LINE_INTERPOLATION_CLOSED_SPLINE)
 				gtk_widget_set_sensitive (widget, FALSE);
-			widget = glade_xml_get_widget (gui, "fill_type_prefs");
+			widget = go_gtk_builder_get_widget (gui, "fill_type_prefs");
 			gtk_box_pack_start (GTK_BOX (box), widget, TRUE, TRUE, 0);
 			g_object_set_data_full (G_OBJECT (widget), "gui", gui,
 						(GDestroyNotify) g_object_unref);
@@ -608,7 +611,8 @@ gog_series_init_style (GogStyledObject *gso, GOStyle *style)
 	GogSeries const *series = (GogSeries const *)gso;
 	style->interesting_fields = series->plot->desc.series.style_fields;
 	gog_theme_fillin_style (gog_object_get_theme (GOG_OBJECT (gso)),
-		style, GOG_OBJECT (gso), series->index, FALSE);
+		style, GOG_OBJECT (gso), series->index,
+	        style->interesting_fields);
 }
 
 static void
@@ -661,7 +665,7 @@ gog_series_class_init (GogSeriesClass *klass)
 	gog_object_register_roles (gog_klass, roles, G_N_ELEMENTS (roles));
 
 	g_object_class_install_property (gobject_klass, SERIES_PROP_HAS_LEGEND,
-		g_param_spec_boolean ("has-legend", 
+		g_param_spec_boolean ("has-legend",
 			_("Has-legend"),
 			_("Should the series show up in legends"),
 			TRUE,
@@ -673,13 +677,13 @@ gog_series_class_init (GogSeriesClass *klass)
 			"linear",
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT | GOG_PARAM_FORCE_SAVE));
 	g_object_class_install_property (gobject_klass, SERIES_PROP_INTERPOLATION_SKIP_INVALID,
-		g_param_spec_boolean ("interpolation-skip-invalid", 
+		g_param_spec_boolean ("interpolation-skip-invalid",
 			_("Interpolation skip invalid"),
 			_("Should the series interpolation ignore the invalid data"),
 			FALSE,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, SERIES_PROP_FILL_TYPE,
-		g_param_spec_string ("fill-type", 
+		g_param_spec_string ("fill-type",
 			_("Fill type"),
 			_("How to fill the area"),
 			"invalid",
@@ -809,7 +813,7 @@ gog_series_dataset_init (GogDatasetClass *iface)
 
 GSF_CLASS_FULL (GogSeries, gog_series,
 		NULL, NULL, gog_series_class_init, NULL,
-		gog_series_init, GOG_TYPE_STYLED_OBJECT, 0,
+		gog_series_init, GOG_TYPE_STYLED_OBJECT, G_TYPE_FLAG_ABSTRACT,
 		GSF_INTERFACE (gog_series_dataset_init, GOG_TYPE_DATASET))
 
 /**
@@ -1026,7 +1030,7 @@ gog_series_get_element (GogSeries const *series, int index)
 		if ((int) element->index == index)
 			return element;
 	}
-	
+
 	return NULL;
 }
 
@@ -1057,14 +1061,14 @@ gog_series_get_data (GogSeries const *series, int *indices, double **data, int n
 				n_points = MIN (vector_n_points, n_points);
 		} else
 			data[i] = NULL;
-	}	
+	}
 
 	return n_points;
 }
 
 unsigned
 gog_series_get_xy_data (GogSeries const  *series,
-			double const 	**x, 
+			double const 	**x,
 			double const 	**y)
 {
 	GogSeriesClass	*klass = GOG_SERIES_GET_CLASS (series);
@@ -1096,8 +1100,8 @@ gog_series_get_xy_data (GogSeries const  *series,
 
 unsigned
 gog_series_get_xyz_data (GogSeries const  *series,
-			 double const 	 **x, 
-			 double const 	 **y, 
+			 double const 	 **x,
+			 double const 	 **y,
 			 double const 	 **z)
 {
 	double *data[3];
